@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--disable-generatedssuper-lookup', '')
@@ -954,55 +954,47 @@ def _cast(typ, value):
 # Data representation classes.
 #
 
-from .enum_import02 import Type02_1
 
-class EnumType01_1(str, Enum):
+class EnumType02_1(str, Enum):
     FLOAT='float'
     INT='int'
     NAME='Name'
     TOKEN='token'
 
 
-class Type01_1(GeneratedsSuper):
+class Type02_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
-        'username': MemberSpec_('username', 'xs:string', 0, 0, {'name': 'username', 'type': 'xs:string'}, None),
-        'inner01': MemberSpec_('inner01', 'Type02_1', 0, 0, {'name': 'inner01', 'type': 'Type02_1'}, None),
+        'userdescription': MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
     }
     subclass = None
     superclass = None
-    def __init__(self, username=None, inner01=None, gds_collector_=None, **kwargs_):
+    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
-        self.username = username
-        self.inner01 = inner01
+        self.userdescription = userdescription
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, Type01_1)
+                CurrentSubclassModule_, Type02_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if Type01_1.subclass:
-            return Type01_1.subclass(*args_, **kwargs_)
+        if Type02_1.subclass:
+            return Type02_1.subclass(*args_, **kwargs_)
         else:
-            return Type01_1(*args_, **kwargs_)
+            return Type02_1(*args_, **kwargs_)
     factory = staticmethod(factory)
-    def get_username(self):
-        return self.username
-    def set_username(self, username):
-        self.username = username
-    def get_inner01(self):
-        return self.inner01
-    def set_inner01(self, inner01):
-        self.inner01 = inner01
+    def get_userdescription(self):
+        return self.userdescription
+    def set_userdescription(self, userdescription):
+        self.userdescription = userdescription
     def hasContent_(self):
         if (
-            self.username is not None or
-            self.inner01 is not None
+            self.userdescription is not None
         ):
             return True
         else:
             return False
-# end class Type01_1
+# end class Type02_1
 
 
 GDSClassesMapping = {
@@ -1013,5 +1005,5 @@ RenameMappings_ = {
 
 }
 __all__ = [
-    "Type01_1"
+    "Type02_1"
 ]
