@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1374,6 +1374,17 @@ if __name__ == '__main__':
 RenameMappings_ = {
 }
 
+#
+# Mapping of namespaces to types defined in them
+# and the file in which each is defined.
+# simpleTypes are marked "ST" and complexTypes "CT".
+NamespaceToDefMappings_ = {'http://www.vmware.com/vcloud/v0.8': [('test1element',
+                                        'tests/anysimpletype.xsd',
+                                        'CT'),
+                                       ('cimAnySimpleType',
+                                        'tests/anysimpletype.xsd',
+                                        'CT')]}
+
 __all__ = [
     "cimAnySimpleType",
     "test1element"
