@@ -2,6 +2,7 @@
 
 #
 # Generated  by generateDS.py.
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -23,70 +24,43 @@
 #   generateds
 #
 
+import os
 import sys
+from lxml import etree as etree_
 
 import anywildcard2_sup as supermod
 
-etree_ = None
-Verbose_import_ = False
-(
-    XMLParser_import_none, XMLParser_import_lxml,
-    XMLParser_import_elementtree
-) = range(3)
-XMLParser_import_library = None
-try:
-    # lxml
-    from lxml import etree as etree_
-    XMLParser_import_library = XMLParser_import_lxml
-    if Verbose_import_:
-        print("running with lxml.etree")
-except ImportError:
-    try:
-        # cElementTree from Python 2.5+
-        import xml.etree.cElementTree as etree_
-        XMLParser_import_library = XMLParser_import_elementtree
-        if Verbose_import_:
-            print("running with cElementTree on Python 2.5+")
-    except ImportError:
-        try:
-            # ElementTree from Python 2.5+
-            import xml.etree.ElementTree as etree_
-            XMLParser_import_library = XMLParser_import_elementtree
-            if Verbose_import_:
-                print("running with ElementTree on Python 2.5+")
-        except ImportError:
-            try:
-                # normal cElementTree install
-                import cElementTree as etree_
-                XMLParser_import_library = XMLParser_import_elementtree
-                if Verbose_import_:
-                    print("running with cElementTree")
-            except ImportError:
-                try:
-                    # normal ElementTree install
-                    import elementtree.ElementTree as etree_
-                    XMLParser_import_library = XMLParser_import_elementtree
-                    if Verbose_import_:
-                        print("running with ElementTree")
-                except ImportError:
-                    raise ImportError(
-                        "Failed to import ElementTree from any known place")
-
-
-def parsexml_(*args, **kwargs):
-    if (XMLParser_import_library == XMLParser_import_lxml and
-            'parser' not in kwargs):
+def parsexml_(infile, parser=None, **kwargs):
+    if parser is None:
         # Use the lxml ElementTree compatible parser so that, e.g.,
         #   we ignore comments.
-        kwargs['parser'] = etree_.ETCompatXMLParser()
-    doc = etree_.parse(*args, **kwargs)
+        parser = etree_.ETCompatXMLParser()
+    try:
+        if isinstance(infile, os.PathLike):
+            infile = os.path.join(infile)
+    except AttributeError:
+        pass
+    doc = etree_.parse(infile, parser=parser, **kwargs)
     return doc
 
+def parsexmlstring_(instring, parser=None, **kwargs):
+    if parser is None:
+        # Use the lxml ElementTree compatible parser so that, e.g.,
+        #   we ignore comments.
+        try:
+            parser = etree_.ETCompatXMLParser()
+        except AttributeError:
+            # fallback to xml.etree
+            parser = etree_.XMLParser()
+    element = etree_.fromstring(instring, parser=parser, **kwargs)
+    return element
+
 #
 # Globals
 #
 
-ExternalEncoding = 'ascii'
+ExternalEncoding = ''
+SaveElementTreeNode = True
 
 #
 # Data representation classes
@@ -94,43 +68,43 @@ ExternalEncoding = 'ascii'
 
 
 class PlantType_singleSub(supermod.PlantType_single):
-    def __init__(self, name=None, anytypeobjs_=None, description=None):
-        super(PlantType_singleSub, self).__init__(name, anytypeobjs_, description, )
+    def __init__(self, name=None, anytypeobjs_=None, description=None, **kwargs_):
+        super(PlantType_singleSub, self).__init__(name, anytypeobjs_, description,  **kwargs_)
 supermod.PlantType_single.subclass = PlantType_singleSub
 # end class PlantType_singleSub
 
 
 class PlantType_multipleSub(supermod.PlantType_multiple):
-    def __init__(self, name=None, anytypeobjs_=None, description=None):
-        super(PlantType_multipleSub, self).__init__(name, anytypeobjs_, description, )
+    def __init__(self, name=None, anytypeobjs_=None, description=None, **kwargs_):
+        super(PlantType_multipleSub, self).__init__(name, anytypeobjs_, description,  **kwargs_)
 supermod.PlantType_multiple.subclass = PlantType_multipleSub
 # end class PlantType_multipleSub
 
 
 class DescriptionTypeSub(supermod.DescriptionType):
-    def __init__(self, name=None, size=None):
-        super(DescriptionTypeSub, self).__init__(name, size, )
+    def __init__(self, name=None, size=None, **kwargs_):
+        super(DescriptionTypeSub, self).__init__(name, size,  **kwargs_)
 supermod.DescriptionType.subclass = DescriptionTypeSub
 # end class DescriptionTypeSub
 
 
 class CatalogTypeSub(supermod.CatalogType):
-    def __init__(self, name=None, catagory=None):
-        super(CatalogTypeSub, self).__init__(name, catagory, )
+    def __init__(self, name=None, catagory=None, **kwargs_):
+        super(CatalogTypeSub, self).__init__(name, catagory,  **kwargs_)
 supermod.CatalogType.subclass = CatalogTypeSub
 # end class CatalogTypeSub
 
 
 class PlantType_single_nochildSub(supermod.PlantType_single_nochild):
-    def __init__(self, anytypeobjs_=None):
-        super(PlantType_single_nochildSub, self).__init__(anytypeobjs_, )
+    def __init__(self, anytypeobjs_=None, **kwargs_):
+        super(PlantType_single_nochildSub, self).__init__(anytypeobjs_,  **kwargs_)
 supermod.PlantType_single_nochild.subclass = PlantType_single_nochildSub
 # end class PlantType_single_nochildSub
 
 
 class PlantType_multiple_nochildSub(supermod.PlantType_multiple_nochild):
-    def __init__(self, anytypeobjs_=None):
-        super(PlantType_multiple_nochildSub, self).__init__(anytypeobjs_, )
+    def __init__(self, anytypeobjs_=None, **kwargs_):
+        super(PlantType_multiple_nochildSub, self).__init__(anytypeobjs_,  **kwargs_)
 supermod.PlantType_multiple_nochild.subclass = PlantType_multiple_nochildSub
 # end class PlantType_multiple_nochildSub
 
@@ -145,7 +119,8 @@ def get_root_tag(node):
 
 
 def parse(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -154,7 +129,9 @@ def parse(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -165,7 +142,8 @@ def parse(inFilename, silence=False):
 
 
 def parseEtree(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -173,11 +151,13 @@ def parseEtree(inFilename, silence=False):
         rootClass = supermod.PlantType_single
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
-    # Enable Python to collect the space used by the DOM.
-    doc = None
     mapping = {}
     rootElement = rootObj.to_etree(None, name_=rootTag, mapping_=mapping)
     reverse_mapping = rootObj.gds_reverse_node_mapping(mapping)
+    # Enable Python to collect the space used by the DOM.
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         content = etree_.tostring(
 ##             rootElement, pretty_print=True,
@@ -188,9 +168,12 @@ def parseEtree(inFilename, silence=False):
 
 
 def parseString(inString, silence=False):
-    from StringIO import StringIO
-    doc = parsexml_(StringIO(inString))
-    rootNode = doc.getroot()
+    if sys.version_info.major == 2:
+        from StringIO import StringIO
+    else:
+        from io import BytesIO as StringIO
+    parser = None
+    rootNode= parsexmlstring_(inString, parser)
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
         rootTag = 'PlantType_single'
@@ -198,7 +181,8 @@ def parseString(inString, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
@@ -208,7 +192,8 @@ def parseString(inString, silence=False):
 
 
 def parseLiteral(inFilename, silence=False):
-    doc = parsexml_(inFilename)
+    parser = None
+    doc = parsexml_(inFilename, parser)
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
@@ -217,7 +202,9 @@ def parseLiteral(inFilename, silence=False):
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
     # Enable Python to collect the space used by the DOM.
-    doc = None
+    if not SaveElementTreeNode:
+        doc = None
+        rootNode = None
 ##     if not silence:
 ##         sys.stdout.write('#from anywildcard2_sup import *\n\n')
 ##         sys.stdout.write('import anywildcard2_sup as model_\n\n')
@@ -233,7 +220,7 @@ Usage: python ???.py <infilename>
 
 
 def usage():
-    print USAGE_TEXT
+    print(USAGE_TEXT)
     sys.exit(1)
 
 
