@@ -2,7 +2,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.6 (default, Jan  8 2020, 19:59:22)  [GCC 7.3.0]
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -80,13 +80,6 @@ supermod.Items.subclass = ItemsSub
 # end class ItemsSub
 
 
-class itemSub(supermod.item):
-    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None, **kwargs_):
-        super(itemSub, self).__init__(partNum, productName, quantity, USPrice, comment, shipDate,  **kwargs_)
-supermod.item.subclass = itemSub
-# end class itemSub
-
-
 class AddressSub(supermod.Address):
     def __init__(self, name=None, street=None, city=None, extensiontype_=None, **kwargs_):
         super(AddressSub, self).__init__(name, street, city, extensiontype_,  **kwargs_)
@@ -108,6 +101,13 @@ supermod.UKAddress.subclass = UKAddressSub
 # end class UKAddressSub
 
 
+class itemTypeSub(supermod.itemType):
+    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None, **kwargs_):
+        super(itemTypeSub, self).__init__(partNum, productName, quantity, USPrice, comment, shipDate,  **kwargs_)
+supermod.itemType.subclass = itemTypeSub
+# end class itemTypeSub
+
+
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
