@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1131,7 +1131,7 @@ class PurchaseOrderType(GeneratedsSuper):
 class Items(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('item', 'item', 1, 1, {'maxOccurs': 'unbounded', 'minOccurs': '0', 'name': 'item', 'type': 'item'}, None),
+        MemberSpec_('item', 'itemType', 1, 1, {'maxOccurs': 'unbounded', 'minOccurs': '0', 'name': 'item', 'type': 'itemType'}, None),
     ]
     subclass = None
     superclass = None
@@ -1226,291 +1226,13 @@ class Items(GeneratedsSuper):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if nodeName_ == 'item':
-            obj_ = item.factory(parent_object_=self)
+            obj_ = itemType.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.item.append(obj_)
             obj_.original_tagname_ = 'item'
 # end class Items
 
 
-class item(GeneratedsSuper):
-    __hash__ = GeneratedsSuper.__hash__
-    member_data_items_ = [
-        MemberSpec_('partNum', 'ipo:SKU', 0, 0, {'use': 'required'}),
-        MemberSpec_('productName', 'string', 0, 0, {'name': 'productName', 'type': 'string'}, None),
-        MemberSpec_('quantity', ['quantity', 'positiveInteger'], 0, 0, {'name': 'quantity', 'type': 'positiveInteger'}, None),
-        MemberSpec_('USPrice', 'decimal', 0, 0, {'name': 'USPrice', 'type': 'decimal'}, None),
-        MemberSpec_('comment', 'string', 0, 1, {'minOccurs': '0', 'name': 'comment', 'ref': 'comment', 'type': 'string'}, None),
-        MemberSpec_('shipDate', 'date', 0, 1, {'minOccurs': '0', 'name': 'shipDate', 'type': 'date'}, None),
-    ]
-    subclass = None
-    superclass = None
-    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None, gds_collector_=None, **kwargs_):
-        self.gds_collector_ = gds_collector_
-        self.gds_elementtree_node_ = None
-        self.original_tagname_ = None
-        self.parent_object_ = kwargs_.get('parent_object_')
-        self.ns_prefix_ = None
-        self.partNum = _cast(None, partNum)
-        self.partNum_nsprefix_ = None
-        self.productName = productName
-        self.productName_nsprefix_ = None
-        self.quantity = quantity
-        self.quantity_nsprefix_ = None
-        self.USPrice = USPrice
-        self.USPrice_nsprefix_ = None
-        self.comment = comment
-        self.comment_nsprefix_ = None
-        if isinstance(shipDate, BaseStrType_):
-            initvalue_ = datetime_.datetime.strptime(shipDate, '%Y-%m-%d').date()
-        else:
-            initvalue_ = shipDate
-        self.shipDate = initvalue_
-        self.shipDate_nsprefix_ = None
-    def factory(*args_, **kwargs_):
-        if CurrentSubclassModule_ is not None:
-            subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, item)
-            if subclass is not None:
-                return subclass(*args_, **kwargs_)
-        if item.subclass:
-            return item.subclass(*args_, **kwargs_)
-        else:
-            return item(*args_, **kwargs_)
-    factory = staticmethod(factory)
-    def get_ns_prefix_(self):
-        return self.ns_prefix_
-    def set_ns_prefix_(self, ns_prefix):
-        self.ns_prefix_ = ns_prefix
-    def get_productName(self):
-        return self.productName
-    def set_productName(self, productName):
-        self.productName = productName
-    def get_quantity(self):
-        return self.quantity
-    def set_quantity(self, quantity):
-        self.quantity = quantity
-    def get_USPrice(self):
-        return self.USPrice
-    def set_USPrice(self, USPrice):
-        self.USPrice = USPrice
-    def get_comment(self):
-        return self.comment
-    def set_comment(self, comment):
-        self.comment = comment
-    def get_shipDate(self):
-        return self.shipDate
-    def set_shipDate(self, shipDate):
-        self.shipDate = shipDate
-    def get_partNum(self):
-        return self.partNum
-    def set_partNum(self, partNum):
-        self.partNum = partNum
-    def validate_SKU(self, value):
-        # Validate type ipo:SKU, a restriction on string.
-        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
-            if not isinstance(value, str):
-                lineno = self.gds_get_node_lineno_()
-                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (str)' % {"value": value, "lineno": lineno, })
-                return False
-            if not self.gds_validate_simple_patterns(
-                    self.validate_SKU_patterns_, value):
-                self.gds_collector_.add_message('Value "%s" does not match xsd pattern restrictions: %s' % (encode_str_2_3(value), self.validate_SKU_patterns_, ))
-    validate_SKU_patterns_ = [['^(\\d{3}-[A-Z]{2})$']]
-    def hasContent_(self):
-        if (
-            self.productName is not None or
-            self.quantity is not None or
-            self.USPrice is not None or
-            self.comment is not None or
-            self.shipDate is not None
-        ):
-            return True
-        else:
-            return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='item', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('item')
-        if imported_ns_def_ is not None:
-            namespacedef_ = imported_ns_def_
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'item':
-            name_ = self.original_tagname_
-        if UseCapturedNS_ and self.ns_prefix_:
-            namespaceprefix_ = self.ns_prefix_ + ':'
-        showIndent(outfile, level, pretty_print)
-        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
-        already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='item')
-        if self.hasContent_():
-            outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='item', pretty_print=pretty_print)
-            showIndent(outfile, level, pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='item'):
-        if self.partNum is not None and 'partNum' not in already_processed:
-            already_processed.add('partNum')
-            outfile.write(' partNum=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.partNum), input_name='partNum')), ))
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='item', fromsubclass_=False, pretty_print=True):
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.productName is not None:
-            namespaceprefix_ = self.productName_nsprefix_ + ':' if (UseCapturedNS_ and self.productName_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%sproductName>%s</%sproductName>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.productName), input_name='productName')), namespaceprefix_ , eol_))
-        if self.quantity is not None:
-            namespaceprefix_ = self.quantity_nsprefix_ + ':' if (UseCapturedNS_ and self.quantity_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%squantity>%s</%squantity>%s' % (namespaceprefix_ , self.gds_format_integer(self.quantity, input_name='quantity'), namespaceprefix_ , eol_))
-        if self.USPrice is not None:
-            namespaceprefix_ = self.USPrice_nsprefix_ + ':' if (UseCapturedNS_ and self.USPrice_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%sUSPrice>%s</%sUSPrice>%s' % (namespaceprefix_ , self.gds_format_decimal(self.USPrice, input_name='USPrice'), namespaceprefix_ , eol_))
-        if self.comment is not None:
-            namespaceprefix_ = self.comment_nsprefix_ + ':' if (UseCapturedNS_ and self.comment_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%scomment>%s</%scomment>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.comment), input_name='comment')), namespaceprefix_ , eol_))
-        if self.shipDate is not None:
-            namespaceprefix_ = self.shipDate_nsprefix_ + ':' if (UseCapturedNS_ and self.shipDate_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%sshipDate>%s</%sshipDate>%s' % (namespaceprefix_ , self.gds_format_date(self.shipDate, input_name='shipDate'), namespaceprefix_ , eol_))
-    def build(self, node, gds_collector_=None):
-        self.gds_collector_ = gds_collector_
-        if SaveElementTreeNode:
-            self.gds_elementtree_node_ = node
-        already_processed = set()
-        self.ns_prefix_ = node.prefix
-        self.buildAttributes(node, node.attrib, already_processed)
-        for child in node:
-            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
-            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
-        return self
-    def buildAttributes(self, node, attrs, already_processed):
-        value = find_attr_value_('partNum', node)
-        if value is not None and 'partNum' not in already_processed:
-            already_processed.add('partNum')
-            self.partNum = value
-            self.validate_SKU(self.partNum)    # validate type SKU
-    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'productName':
-            value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'productName')
-            value_ = self.gds_validate_string(value_, node, 'productName')
-            self.productName = value_
-            self.productName_nsprefix_ = child_.prefix
-        elif nodeName_ == 'quantity' and child_.text:
-            sval_ = child_.text
-            ival_ = self.gds_parse_integer(sval_, node, 'quantity')
-            if ival_ <= 0:
-                raise_parse_error(child_, 'requires positiveInteger')
-            ival_ = self.gds_validate_integer(ival_, node, 'quantity')
-            self.quantity = ival_
-            self.quantity_nsprefix_ = child_.prefix
-        elif nodeName_ == 'USPrice' and child_.text:
-            sval_ = child_.text
-            fval_ = self.gds_parse_decimal(sval_, node, 'USPrice')
-            fval_ = self.gds_validate_decimal(fval_, node, 'USPrice')
-            self.USPrice = fval_
-            self.USPrice_nsprefix_ = child_.prefix
-        elif nodeName_ == 'comment':
-            value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'comment')
-            value_ = self.gds_validate_string(value_, node, 'comment')
-            self.comment = value_
-            self.comment_nsprefix_ = child_.prefix
-        elif nodeName_ == 'shipDate':
-            sval_ = child_.text
-            dval_ = self.gds_parse_date(sval_)
-            self.shipDate = dval_
-            self.shipDate_nsprefix_ = child_.prefix
-# end class item
-
-
-class quantity(GeneratedsSuper):
-    __hash__ = GeneratedsSuper.__hash__
-    member_data_items_ = [
-    ]
-    subclass = None
-    superclass = None
-    def __init__(self, valueOf_=None, gds_collector_=None, **kwargs_):
-        self.gds_collector_ = gds_collector_
-        self.gds_elementtree_node_ = None
-        self.original_tagname_ = None
-        self.parent_object_ = kwargs_.get('parent_object_')
-        self.ns_prefix_ = None
-        self.valueOf_ = valueOf_
-    def factory(*args_, **kwargs_):
-        if CurrentSubclassModule_ is not None:
-            subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, quantity)
-            if subclass is not None:
-                return subclass(*args_, **kwargs_)
-        if quantity.subclass:
-            return quantity.subclass(*args_, **kwargs_)
-        else:
-            return quantity(*args_, **kwargs_)
-    factory = staticmethod(factory)
-    def get_ns_prefix_(self):
-        return self.ns_prefix_
-    def set_ns_prefix_(self, ns_prefix):
-        self.ns_prefix_ = ns_prefix
-    def hasContent_(self):
-        if (
-
-        ):
-            return True
-        else:
-            return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO"', name_='quantity', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('quantity')
-        if imported_ns_def_ is not None:
-            namespacedef_ = imported_ns_def_
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'quantity':
-            name_ = self.original_tagname_
-        if UseCapturedNS_ and self.ns_prefix_:
-            namespaceprefix_ = self.ns_prefix_ + ':'
-        showIndent(outfile, level, pretty_print)
-        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
-        already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='quantity')
-        if self.hasContent_():
-            outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='quantity', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='quantity'):
-        pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO"', name_='quantity', fromsubclass_=False, pretty_print=True):
-        pass
-    def build(self, node, gds_collector_=None):
-        self.gds_collector_ = gds_collector_
-        if SaveElementTreeNode:
-            self.gds_elementtree_node_ = node
-        already_processed = set()
-        self.ns_prefix_ = node.prefix
-        self.buildAttributes(node, node.attrib, already_processed)
-        for child in node:
-            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
-            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
-        return self
-    def buildAttributes(self, node, attrs, already_processed):
-        pass
-    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        pass
-# end class quantity
-
-
 class Address(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1933,6 +1655,221 @@ class UKAddress(Address):
 # end class UKAddress
 
 
+class itemType(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = [
+        MemberSpec_('partNum', 'ipo:SKU', 0, 0, {'use': 'required'}),
+        MemberSpec_('productName', 'string', 0, 0, {'name': 'productName', 'type': 'string'}, None),
+        MemberSpec_('quantity', ['quantityType', 'positiveInteger'], 0, 0, {'name': 'quantity', 'type': 'positiveInteger'}, None),
+        MemberSpec_('USPrice', 'decimal', 0, 0, {'name': 'USPrice', 'type': 'decimal'}, None),
+        MemberSpec_('comment', 'string', 0, 1, {'minOccurs': '0', 'name': 'comment', 'ref': 'comment', 'type': 'string'}, None),
+        MemberSpec_('shipDate', 'date', 0, 1, {'minOccurs': '0', 'name': 'shipDate', 'type': 'date'}, None),
+    ]
+    subclass = None
+    superclass = None
+    def __init__(self, partNum=None, productName=None, quantity=None, USPrice=None, comment=None, shipDate=None, gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.gds_elementtree_node_ = None
+        self.original_tagname_ = None
+        self.parent_object_ = kwargs_.get('parent_object_')
+        self.ns_prefix_ = None
+        self.partNum = _cast(None, partNum)
+        self.partNum_nsprefix_ = None
+        self.productName = productName
+        self.productName_nsprefix_ = None
+        self.quantity = quantity
+        self.validate_quantityType(self.quantity)
+        self.quantity_nsprefix_ = None
+        self.USPrice = USPrice
+        self.USPrice_nsprefix_ = None
+        self.comment = comment
+        self.comment_nsprefix_ = None
+        if isinstance(shipDate, BaseStrType_):
+            initvalue_ = datetime_.datetime.strptime(shipDate, '%Y-%m-%d').date()
+        else:
+            initvalue_ = shipDate
+        self.shipDate = initvalue_
+        self.shipDate_nsprefix_ = None
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, itemType)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if itemType.subclass:
+            return itemType.subclass(*args_, **kwargs_)
+        else:
+            return itemType(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_ns_prefix_(self):
+        return self.ns_prefix_
+    def set_ns_prefix_(self, ns_prefix):
+        self.ns_prefix_ = ns_prefix
+    def get_productName(self):
+        return self.productName
+    def set_productName(self, productName):
+        self.productName = productName
+    def get_quantity(self):
+        return self.quantity
+    def set_quantity(self, quantity):
+        self.quantity = quantity
+    def get_USPrice(self):
+        return self.USPrice
+    def set_USPrice(self, USPrice):
+        self.USPrice = USPrice
+    def get_comment(self):
+        return self.comment
+    def set_comment(self, comment):
+        self.comment = comment
+    def get_shipDate(self):
+        return self.shipDate
+    def set_shipDate(self, shipDate):
+        self.shipDate = shipDate
+    def get_partNum(self):
+        return self.partNum
+    def set_partNum(self, partNum):
+        self.partNum = partNum
+    def validate_quantityType(self, value):
+        result = True
+        # Validate type quantityType, a restriction on positiveInteger.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, int):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (int)' % {"value": value, "lineno": lineno, })
+                return False
+            if value >= 100:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd maxExclusive restriction on quantityType' % {"value": value, "lineno": lineno} )
+                result = False
+        return result
+    def validate_SKU(self, value):
+        # Validate type ipo:SKU, a restriction on string.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, str):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (str)' % {"value": value, "lineno": lineno, })
+                return False
+            if not self.gds_validate_simple_patterns(
+                    self.validate_SKU_patterns_, value):
+                self.gds_collector_.add_message('Value "%s" does not match xsd pattern restrictions: %s' % (encode_str_2_3(value), self.validate_SKU_patterns_, ))
+    validate_SKU_patterns_ = [['^(\\d{3}-[A-Z]{2})$']]
+    def hasContent_(self):
+        if (
+            self.productName is not None or
+            self.quantity is not None or
+            self.USPrice is not None or
+            self.comment is not None or
+            self.shipDate is not None
+        ):
+            return True
+        else:
+            return False
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='itemType', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('itemType')
+        if imported_ns_def_ is not None:
+            namespacedef_ = imported_ns_def_
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.original_tagname_ is not None and name_ == 'itemType':
+            name_ = self.original_tagname_
+        if UseCapturedNS_ and self.ns_prefix_:
+            namespaceprefix_ = self.ns_prefix_ + ':'
+        showIndent(outfile, level, pretty_print)
+        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
+        already_processed = set()
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='itemType')
+        if self.hasContent_():
+            outfile.write('>%s' % (eol_, ))
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='itemType', pretty_print=pretty_print)
+            showIndent(outfile, level, pretty_print)
+            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
+        else:
+            outfile.write('/>%s' % (eol_, ))
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='itemType'):
+        if self.partNum is not None and 'partNum' not in already_processed:
+            already_processed.add('partNum')
+            outfile.write(' partNum=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.partNum), input_name='partNum')), ))
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:ipo="http://www.example.com/IPO" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='itemType', fromsubclass_=False, pretty_print=True):
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.productName is not None:
+            namespaceprefix_ = self.productName_nsprefix_ + ':' if (UseCapturedNS_ and self.productName_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sproductName>%s</%sproductName>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.productName), input_name='productName')), namespaceprefix_ , eol_))
+        if self.quantity is not None:
+            namespaceprefix_ = self.quantity_nsprefix_ + ':' if (UseCapturedNS_ and self.quantity_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%squantity>%s</%squantity>%s' % (namespaceprefix_ , self.gds_format_integer(self.quantity, input_name='quantity'), namespaceprefix_ , eol_))
+        if self.USPrice is not None:
+            namespaceprefix_ = self.USPrice_nsprefix_ + ':' if (UseCapturedNS_ and self.USPrice_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sUSPrice>%s</%sUSPrice>%s' % (namespaceprefix_ , self.gds_format_decimal(self.USPrice, input_name='USPrice'), namespaceprefix_ , eol_))
+        if self.comment is not None:
+            namespaceprefix_ = self.comment_nsprefix_ + ':' if (UseCapturedNS_ and self.comment_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%scomment>%s</%scomment>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.comment), input_name='comment')), namespaceprefix_ , eol_))
+        if self.shipDate is not None:
+            namespaceprefix_ = self.shipDate_nsprefix_ + ':' if (UseCapturedNS_ and self.shipDate_nsprefix_) else ''
+            showIndent(outfile, level, pretty_print)
+            outfile.write('<%sshipDate>%s</%sshipDate>%s' % (namespaceprefix_ , self.gds_format_date(self.shipDate, input_name='shipDate'), namespaceprefix_ , eol_))
+    def build(self, node, gds_collector_=None):
+        self.gds_collector_ = gds_collector_
+        if SaveElementTreeNode:
+            self.gds_elementtree_node_ = node
+        already_processed = set()
+        self.ns_prefix_ = node.prefix
+        self.buildAttributes(node, node.attrib, already_processed)
+        for child in node:
+            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
+            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
+        return self
+    def buildAttributes(self, node, attrs, already_processed):
+        value = find_attr_value_('partNum', node)
+        if value is not None and 'partNum' not in already_processed:
+            already_processed.add('partNum')
+            self.partNum = value
+            self.validate_SKU(self.partNum)    # validate type SKU
+    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+        if nodeName_ == 'productName':
+            value_ = child_.text
+            value_ = self.gds_parse_string(value_, node, 'productName')
+            value_ = self.gds_validate_string(value_, node, 'productName')
+            self.productName = value_
+            self.productName_nsprefix_ = child_.prefix
+        elif nodeName_ == 'quantity' and child_.text:
+            sval_ = child_.text
+            ival_ = self.gds_parse_integer(sval_, node, 'quantity')
+            if ival_ <= 0:
+                raise_parse_error(child_, 'requires positiveInteger')
+            ival_ = self.gds_validate_integer(ival_, node, 'quantity')
+            self.quantity = ival_
+            self.quantity_nsprefix_ = child_.prefix
+            # validate type quantityType
+            self.validate_quantityType(self.quantity)
+        elif nodeName_ == 'USPrice' and child_.text:
+            sval_ = child_.text
+            fval_ = self.gds_parse_decimal(sval_, node, 'USPrice')
+            fval_ = self.gds_validate_decimal(fval_, node, 'USPrice')
+            self.USPrice = fval_
+            self.USPrice_nsprefix_ = child_.prefix
+        elif nodeName_ == 'comment':
+            value_ = child_.text
+            value_ = self.gds_parse_string(value_, node, 'comment')
+            value_ = self.gds_validate_string(value_, node, 'comment')
+            self.comment = value_
+            self.comment_nsprefix_ = child_.prefix
+        elif nodeName_ == 'shipDate':
+            sval_ = child_.text
+            dval_ = self.gds_parse_date(sval_)
+            self.shipDate = dval_
+            self.shipDate_nsprefix_ = child_.prefix
+# end class itemType
+
+
 GDSClassesMapping = {
     'purchaseOrder': PurchaseOrderType,
 }
@@ -2123,10 +2060,24 @@ if __name__ == '__main__':
 RenameMappings_ = {
 }
 
+#
+# Mapping of namespaces to types defined in them
+# and the file in which each is defined.
+# simpleTypes are marked "ST" and complexTypes "CT".
+NamespaceToDefMappings_ = {'http://www.example.com/IPO': [('USState', 'tests/address.xsd', 'ST'),
+                                ('UKPostcode', 'tests/address.xsd', 'ST'),
+                                ('Address', 'tests/address.xsd', 'CT'),
+                                ('USAddress', 'tests/address.xsd', 'CT'),
+                                ('UKAddress', 'tests/address.xsd', 'CT'),
+                                ('SKU', 'tests/ipo.xsd', 'ST'),
+                                ('PurchaseOrderType', 'tests/ipo.xsd', 'CT'),
+                                ('Items', 'tests/ipo.xsd', 'CT')]}
+
 __all__ = [
     "Address",
     "Items",
     "PurchaseOrderType",
     "UKAddress",
-    "USAddress"
+    "USAddress",
+    "itemType"
 ]
