@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
+# Python 3.8.3 (default, Jul  2 2020, 16:21:59)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -973,7 +973,7 @@ class Wheel(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
         MemberSpec_('description', 'string', 0, 0, {'name': 'description', 'type': 'string'}, None),
-        MemberSpec_('radius', ['radius', 'float'], 0, 0, {'name': 'radius', 'type': 'float'}, None),
+        MemberSpec_('radius', ['radiusType', 'float'], 0, 0, {'name': 'radius', 'type': 'float'}, None),
     ]
     subclass = None
     superclass = None
@@ -986,6 +986,7 @@ class Wheel(GeneratedsSuper):
         self.description = description
         self.description_nsprefix_ = None
         self.radius = radius
+        self.validate_radiusType(self.radius)
         self.radius_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1010,6 +1011,19 @@ class Wheel(GeneratedsSuper):
         return self.radius
     def set_radius(self, radius):
         self.radius = radius
+    def validate_radiusType(self, value):
+        result = True
+        # Validate type radiusType, a restriction on float.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, float):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (float)' % {"value": value, "lineno": lineno, })
+                return False
+            if value < 0:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd minInclusive restriction on radiusType' % {"value": value, "lineno": lineno} )
+                result = False
+        return result
     def hasContent_(self):
         if (
             self.description is not None or
@@ -1086,88 +1100,11 @@ class Wheel(GeneratedsSuper):
             fval_ = self.gds_validate_float(fval_, node, 'radius')
             self.radius = fval_
             self.radius_nsprefix_ = child_.prefix
+            # validate type radiusType
+            self.validate_radiusType(self.radius)
 # end class Wheel
 
 
-class radius(GeneratedsSuper):
-    __hash__ = GeneratedsSuper.__hash__
-    member_data_items_ = [
-    ]
-    subclass = None
-    superclass = None
-    def __init__(self, valueOf_=None, gds_collector_=None, **kwargs_):
-        self.gds_collector_ = gds_collector_
-        self.gds_elementtree_node_ = None
-        self.original_tagname_ = None
-        self.parent_object_ = kwargs_.get('parent_object_')
-        self.ns_prefix_ = None
-        self.valueOf_ = valueOf_
-    def factory(*args_, **kwargs_):
-        if CurrentSubclassModule_ is not None:
-            subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, radius)
-            if subclass is not None:
-                return subclass(*args_, **kwargs_)
-        if radius.subclass:
-            return radius.subclass(*args_, **kwargs_)
-        else:
-            return radius(*args_, **kwargs_)
-    factory = staticmethod(factory)
-    def get_ns_prefix_(self):
-        return self.ns_prefix_
-    def set_ns_prefix_(self, ns_prefix):
-        self.ns_prefix_ = ns_prefix
-    def hasContent_(self):
-        if (
-
-        ):
-            return True
-        else:
-            return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/"', name_='radius', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('radius')
-        if imported_ns_def_ is not None:
-            namespacedef_ = imported_ns_def_
-        if pretty_print:
-            eol_ = '\n'
-        else:
-            eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'radius':
-            name_ = self.original_tagname_
-        if UseCapturedNS_ and self.ns_prefix_:
-            namespaceprefix_ = self.ns_prefix_ + ':'
-        showIndent(outfile, level, pretty_print)
-        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
-        already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='radius')
-        if self.hasContent_():
-            outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='radius', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='radius'):
-        pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/"', name_='radius', fromsubclass_=False, pretty_print=True):
-        pass
-    def build(self, node, gds_collector_=None):
-        self.gds_collector_ = gds_collector_
-        if SaveElementTreeNode:
-            self.gds_elementtree_node_ = node
-        already_processed = set()
-        self.ns_prefix_ = node.prefix
-        self.buildAttributes(node, node.attrib, already_processed)
-        for child in node:
-            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
-            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
-        return self
-    def buildAttributes(self, node, attrs, already_processed):
-        pass
-    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        pass
-# end class radius
-
-
 GDSClassesMapping = {
     'Wheel': Wheel,
 }
@@ -1358,6 +1295,14 @@ if __name__ == '__main__':
 RenameMappings_ = {
 }
 
+#
+# Mapping of namespaces to types defined in them
+# and the file in which each is defined.
+# simpleTypes are marked "ST" and complexTypes "CT".
+NamespaceToDefMappings_ = {'http://www.example.org/wheel/': [('Wheel',
+                                    'tests/preserve_cdata_tags.xsd',
+                                    'CT')]}
+
 __all__ = [
     "Wheel"
 ]
